;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "elmpd" "20250910.327"
  "A tight, ergonomic, async client library for mpd."
  '((emacs "25.1"))
  :url "https://github.com/sp1ff/elmpd"
  :commit "a68563fa3e3b09fcdaf4b9f070542f8cfa257067"
  :revdesc "a68563fa3e3b"
  :keywords '("comm")
  :authors '(("Michael Herstine" . "sp1ff@pobox.com"))
  :maintainers '(("Michael Herstine" . "sp1ff@pobox.com")))
